  ##############################################################################
 #  Data::Deep/TEST  : zap() function
  ##############################################################################
;# Tests related to key in use with search and compare functions of Data::Deep
 ###############################################################################
 ### zap.t
###
##
#
#
# Before `make install' is performed this script should be runnable with
# `make test'. After `make install' it should work as `perl test.pl'

START_TEST_MODULE(__FILE__);

  use Data::Deep qw(:config);




# test le zap avec tous les types 
#mettre ici le test de boucle



END_TEST_MODULE(__FILE__);
